@@ -64,7 +64,11 @@ def restore_ladok_session(credentials):
       key = base64.urlsafe_b64encode(kdf.derive(credentials[1].encode("utf-8")))
 
       fernet_protocol = Fernet(key)
-      pickled_ls = fernet_protocol.decrypt(encrypted_ls)
+      try:
+        pickled_ls = fernet_protocol.decrypt(encrypted_ls)
+      except Exception as err:
+        warn(f"cache was corrupted, cannot decrypt: {err}")
+        pickled_ls = None
       return pickle.loads(pickled_ls)
 
   return None
